# z4d-certified-devices

## Overview

This package is required for the [Zigbee for Domoticz](https://github.com/zigbeefordomoticz/Domoticz-Zigbee) plugin.
It provides configuration files to optimized the pairing and behaviour of Zigbee devices connected to the plugin.
This package is part of the Zigbee4Domoticz requirements and should be installed defacto.


## how to install from the github 

```python
sudo python3 -m pip install git+https://github.com/zigbeefordomoticz/z4d-certified-devices
```


## how to install from PyPi

sudo python3 -m pip install z4d-certified-devices --upgrade

# Donations and Sponsorship

We warmly invite Manufacturers and sellers to contribute by sending us samples of their devices for integration. Your support in this regard is greatly appreciated as it enables us to expand our compatibility and offer a more comprehensive solution.

We extend our heartfelt gratitude to our generous donors whose contributions enable us to acquire additional equipment for rigorous testing and seamless integration. With your support, we can further enhance the plugin's capabilities and deliver an even more powerful and versatile experience for our users.

* <img src="https://www.pipiche.fr//pp.svg" width="24" height="24" alt="Donate via Paypal"/> <a href="https://paypal.me/pipiche">Donate via PayPal</a>
<br/>
